@@ -16,9 +16,9 @@ import os
 import platform
 import re
 import shutil
-from socket import gethostbyname
 import sys
-from typing import Any, Mapping, Optional, Tuple, Union, List
+from socket import gethostbyname
+from typing import Any, List, Mapping, Optional, Tuple, Union
 
 import nox.command
 import py
@@ -139,17 +139,6 @@ def locate_using_path_and_version(version: str) -> Optional[str]:
     return None
 
 
-def _clean_location(self: "Union[CondaEnv, VirtualEnv]") -> bool:
-    """Deletes any existing path-based environment"""
-    if os.path.exists(self.location):
-        if self.reuse_existing:
-            return False
-        else:
-            shutil.rmtree(self.location)
-
-    return True
-
-
 class PassthroughEnv(ProcessEnv):
     """Represents the environment used to run nox itself
 
@@ -200,7 +189,21 @@ class CondaEnv(ProcessEnv):
         self.venv_params = venv_params if venv_params else []
         super(CondaEnv, self).__init__()
 
-    _clean_location = _clean_location
+    def _clean_location(self) -> bool:
+        """Deletes existing conda environment"""
+        if os.path.exists(self.location):
+            if self.reuse_existing:
+                return False
+            else:
+                cmd = ["conda", "remove", "--yes", "--prefix", self.location, "--all"]
+                nox.command.run(cmd, silent=True, log=False)
+                # Make sure that location is clean
+                try:
+                    shutil.rmtree(self.location)
+                except FileNotFoundError:
+                    pass
+
+        return True
 
     @property
     def bin_paths(self) -> List[str]:
@@ -302,7 +305,15 @@ class VirtualEnv(ProcessEnv):
         self.venv_params = venv_params if venv_params else []
         super(VirtualEnv, self).__init__(env={"VIRTUAL_ENV": self.location})
 
-    _clean_location = _clean_location
+    def _clean_location(self) -> bool:
+        """Deletes any existing virtual environment"""
+        if os.path.exists(self.location):
+            if self.reuse_existing:
+                return False
+            else:
+                shutil.rmtree(self.location)
+
+        return True
 
     @property
     def _resolved_interpreter(self) -> str:
@@ -330,7 +341,7 @@ class VirtualEnv(ProcessEnv):
 
         # If this is just a X, X.Y, or X.Y.Z string, extract just the X / X.Y
         # part and add Python to the front of it.
-        match = re.match(r"^(?P<xy_ver>\d(\.\d)?)(\.\d+)?$", self.interpreter)
+        match = re.match(r"^(?P<xy_ver>\d(\.\d+)?)(\.\d+)?$", self.interpreter)
         if match:
             xy_version = match.group("xy_ver")
             cleaned_interpreter = "python{}".format(xy_version)
@@ -347,7 +358,7 @@ class VirtualEnv(ProcessEnv):
             raise self._resolved
 
         # Allow versions of the form ``X.Y-32`` for Windows.
-        match = re.match(r"^\d\.\d-32?$", cleaned_interpreter)
+        match = re.match(r"^\d\.\d+-32?$", cleaned_interpreter)
         if match:
             # preserve the "-32" suffix, as the Python launcher expects
             # it.
